<?php

/**
 * Covnoy Automatic Stock admin_manage_plugin controller
 * 
 * @var Controller $this
 * 
 * @link https://aleksa.tf Aleksa Đorđić
 * @link https://code-cats.com Code Cats
 */
class AdminManagePlugin extends AppController
{
    private function init()
    {
        $this->parent->requireLogin();

        Language::loadLang(
            'admin_manage_plugin',
            null,
            PLUGINDIR . 'convoy_automatic_stock' . DS . 'language' . DS
        );

        $this->parent->structure->set('page_title', Language::_('AdminManage.index.page_title', true));
        $this->view->setView(null, 'ConvoyAutomaticStock.default');

        $this->company_id = Configure::get('Blesta.company_id');
        $this->uses(['ConvoyAutomaticStock.ConvoyStockSettings', 'ModuleManager']);
    }

    public function index()
    {
        $this->init();

        if (!empty($this->post)) {
            $data = $this->post;
            $data['company_id'] = $this->company_id;

            $checkboxes = ['enabled'];
            foreach ($checkboxes as $checkbox) {
                if (!isset($data[$checkbox])) {
                    $data[$checkbox] = '0';
                }
            }

            // Add the page
            if (!$this->ConvoyStockSettings->get($this->company_id)) {
                $this->ConvoyStockSettings->add($data);
            } else {
                $this->ConvoyStockSettings->edit($this->company_id, $data);
            }

            if (($errors = $this->ConvoyStockSettings->errors())) {
                // Error, reset vars
                $vars = (object)$this->post;
                $this->parent->setMessage('error', $errors);
            } else {
                if (isset($data['save_run'])) {    
                    Loader::load(dirname(__DIR__, 1) . DS . 'convoy_automatic_stock_plugin.php');
                    $plugin = new ConvoyAutomaticStockPlugin();
                    $plugin->updateStock();
                }

                // Success
                //$this->parent->flashMessage('message', Language::_('AdminManage.index.success', true));
                //$this->redirect($this->base_uri . 'settings/company/plugins/installed/');
            }
        }

        if (!isset($vars)) {
            $vars = $this->ConvoyStockSettings->get($this->company_id);
        }

        $modules = $this->ModuleManager->getAll($this->company_id);

        return $this->partial('admin_manage_plugin', [
            'modules' => isset($modules) ? array_reduce($modules, [$this, 'getSelectArray'], ['-1' => Language::_('AdminManage.index.no_module', true)]) : null,
            'vars' => $vars
        ]);
    }

    private function getSelectArray(&$result, $item)
    {
        $result[$item->id] = $item->name;
        return $result;
    }
}